Changelog
=========

next
----
#. String representation for Python 3.

2.0.1
-----
#. Django 2.1 support. The minimum supported Django version is now 1.11.
#. Added coveralls

2.0.0
-----
#. Django 2 support. The minimum supported Django version is now 1.10.

1.11.0
------
#. Compatibility for Python 3.5 and Django 1.11.

1.9
---
#. Actual unit tests.
#. Compatibility from Django 1.6 to 1.9.

0.1.3
-----
#. __unicode__ method now returns a sensible result.

0.1.2
-----
#. Fix tree view.

0.1.1
-----
#. Added sites and subtitle fields.

0.1
---
#. Dependency cleanup.

0.0.6
-----
#. Added get_absolute_url on Category

0.0.5
-----
#. Use prepopulate_fields for admin interface
#. Parent category field added
#. South migration path created
#. Tree view of categories and tags

0.0.4 (2011-08-24)
------------------
#. Docs, testrunner.

